@@ -1,18 +1,36 @@
 package Email::Sender::Role::CommonSending;
-{
-  $Email::Sender::Role::CommonSending::VERSION = '1.300006';
-}
-use Moo::Role;
 # ABSTRACT: the common sending tasks most Email::Sender classes will need
+$Email::Sender::Role::CommonSending::VERSION = '1.300011';
+use Moo::Role;
 
 use Carp ();
-use Email::Abstract;
+use Email::Abstract 3.006;
 use Email::Sender::Success;
 use Email::Sender::Failure::Temporary;
 use Email::Sender::Failure::Permanent;
 use Scalar::Util ();
 use Try::Tiny;
 
+# =head1 DESCRIPTION
+#
+# Email::Sender::Role::CommonSending provides a number of features that should
+# ease writing new classes that perform the L<Email::Sender> role.  Instead of
+# writing a C<send> method, implementors will need to write a smaller
+# C<send_email> method, which will be passed an L<Email::Abstract> object and
+# envelope containing C<from> and C<to> entries.  The C<to> entry will be
+# guaranteed to be an array reference.
+#
+# A C<success> method will also be provided as a shortcut for calling:
+#
+#   Email::Sender::Success->new(...);
+#
+# A few other minor details are handled by CommonSending; for more information,
+# consult the source.
+#
+# The methods documented here may be overridden to alter the behavior of the
+# CommonSending role.
+#
+# =cut
 
 with 'Email::Sender';
 
@@ -39,6 +57,12 @@ sub send {
   }
 }
 
+# =method prepare_email
+#
+# This method is passed a scalar and is expected to return an Email::Abstract
+# object.  You probably shouldn't override it in most cases.
+#
+# =cut
 
 sub prepare_email {
   my ($self, $msg) = @_;
@@ -54,6 +78,13 @@ sub prepare_email {
   return Email::Abstract->new($msg);
 }
 
+# =method prepare_envelope
+#
+# This method is passed a hashref and returns a new hashref that should be used
+# as the envelope passed to the C<send_email> method.  This method is responsible
+# for ensuring that the F<to> entry is an array.
+#
+# =cut
 
 sub prepare_envelope {
   my ($self, $env) = @_;
@@ -65,6 +96,16 @@ sub prepare_envelope {
   return \%new_env;
 }
 
+# =method success
+#
+#   ...
+#   return $self->success;
+#
+# This method returns a new Email::Sender::Success object.  Arguments passed to
+# this method are passed along to the Success's constructor.  This is provided as
+# a convenience for returning success from subclasses' C<send_email> methods.
+#
+# =cut
 
 sub success {
   my $self = shift;
@@ -78,13 +119,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Role::CommonSending - the common sending tasks most Email::Sender classes will need
 
 =head1 VERSION
 
-version 1.300006
+version 1.300011
 
 =head1 DESCRIPTION
 
@@ -133,7 +176,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo Signes.
+This software is copyright (c) 2014 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
