@@ -1,20 +1,39 @@
 package Email::Sender::Transport::Maildir;
-{
-  $Email::Sender::Transport::Maildir::VERSION = '1.300006';
-}
+# ABSTRACT: deliver mail to a maildir on disk
+$Email::Sender::Transport::Maildir::VERSION = '1.300011';
 use Moo;
 with 'Email::Sender::Transport';
-# ABSTRACT: deliver mail to a maildir on disk
 
 use Errno ();
 use Fcntl;
-use File::Path;
+use File::Path 2.06;
 use File::Spec;
 
 use Sys::Hostname;
 
 use MooX::Types::MooseLike::Base qw(Bool);
 
+# =head1 DESCRIPTION
+#
+# This transport delivers into a maildir.  The maildir's location may be given as
+# the F<dir> argument to the constructor, and defaults to F<Maildir> in the
+# current directory (at the time of transport initialization).
+#
+# If the directory does not exist, it will be created.
+#
+# By default, three headers will be added:
+#
+#  * X-Email-Sender-From - the envelope sender
+#  * X-Email-Sender-To   - the envelope recipients (one header per rcpt)
+#  * Lines               - the number of lines in the body
+#
+# These can be controlled with the C<add_lines_header> and
+# C<add_envelope_headers> constructor arguments.
+#
+# The L<Email::Sender::Success> object returned on success has a C<filename>
+# method that returns the filename to which the message was delivered.
+#
+# =cut
 
 {
   package
@@ -80,7 +99,7 @@ sub _ensure_maildir_exists {
     next if -d $subdir;
 
     Email::Sender::Failure->throw("couldn't create $subdir: $!")
-      unless File::Path::mkpath($subdir);
+      unless File::Path::make_path($subdir) || -d $subdir;
   }
 }
 
@@ -109,7 +128,9 @@ sub _deliver_email {
   # if (eval { $email->can('stream_to') }) {
   #  eval { $mail->stream_to($fh); 1 } or return;
   #} else {
-  print $tmp_fh $email->as_string
+  my $string = $email->as_string;
+  $string =~ s/\x0D\x0A/\x0A/g unless $^O eq 'MSWin32';
+  print $tmp_fh $string
     or Email::Sender::Failure->throw("could not write to $tmp_filename: $!");
 
   close $tmp_fh
@@ -153,13 +174,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Transport::Maildir - deliver mail to a maildir on disk
 
 =head1 VERSION
 
-version 1.300006
+version 1.300011
 
 =head1 DESCRIPTION
 
@@ -187,7 +210,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo Signes.
+This software is copyright (c) 2014 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
