@@ -1,15 +1,38 @@
 package Email::Sender::Transport::SMTP;
-{
-  $Email::Sender::Transport::SMTP::VERSION = '1.300006';
-}
-use Moo;
-use MooX::Types::MooseLike::Base qw(Bool Int Str);
 # ABSTRACT: send email over SMTP
+$Email::Sender::Transport::SMTP::VERSION = '1.300011';
+use Moo;
 
 use Email::Sender::Failure::Multi;
 use Email::Sender::Success::Partial;
+use Email::Sender::Role::HasMessage ();
 use Email::Sender::Util;
+use MooX::Types::MooseLike::Base qw(Bool Int Str);
 
+# =head1 DESCRIPTION
+#
+# This transport is used to send email over SMTP, either with or without secure
+# sockets (SSL).  It is one of the most complex transports available, capable of
+# partial success.
+#
+# For a potentially more efficient version of this transport, see
+# L<Email::Sender::Transport::SMTP::Persistent>.
+#
+# =head1 ATTRIBUTES
+#
+# The following attributes may be passed to the constructor:
+#
+# =over 4
+#
+# =item C<host>: the name of the host to connect to; defaults to C<localhost>
+#
+# =item C<ssl>: if true, connect via SSL; defaults to false
+#
+# =item C<port>: port to connect to; defaults to 25 for non-SSL, 465 for SSL
+#
+# =item C<timeout>: maximum time in secs to wait for server; default is 120
+#
+# =cut
 
 has host => (is => 'ro', isa => Str,  default => sub { 'localhost' });
 has ssl  => (is => 'ro', isa => Bool, default => sub { 0 });
@@ -22,17 +45,39 @@ has port => (
 
 has timeout => (is => 'ro', isa => Int, default => sub { 120 });
 
+# =item C<sasl_username>: the username to use for auth; optional
+#
+# =item C<sasl_password>: the password to use for auth; required if C<username> is provided
+#
+# =item C<allow_partial_success>: if true, will send data even if some recipients were rejected; defaults to false
+#
+# =cut
 
 has sasl_username => (is => 'ro', isa => Str);
 has sasl_password => (is => 'ro', isa => Str);
 
 has allow_partial_success => (is => 'ro', isa => Bool, default => sub { 0 });
 
+# =item C<helo>: what to say when saying HELO; no default
+#
+# =item C<localaddr>: local address from which to connect
+#
+# =item C<localport>: local port from which to connect
+#
+# =cut
 
 has helo      => (is => 'ro', isa => Str);
 has localaddr => (is => 'ro');
 has localport => (is => 'ro', isa => Int);
 
+# =item C<debug>: if true, put the L<Net::SMTP> object in debug mode
+#
+# =back
+#
+# =cut
+
+has debug => (is => 'ro', isa => Bool, default => sub { 0 });
+
 # I am basically -sure- that this is wrong, but sending hundreds of millions of
 # messages has shown that it is right enough.  I will try to make it textbook
 # later. -- rjbs, 2008-12-05
@@ -85,6 +130,7 @@ sub _net_smtp_args {
     $self->host,
     Port    => $self->port,
     Timeout => $self->timeout,
+    Debug   => $self->debug,
     defined $self->helo      ? (Hello     => $self->helo)      : (),
     defined $self->localaddr ? (LocalAddr => $self->localaddr) : (),
     defined $self->localport ? (LocalPort => $self->localport) : (),
@@ -107,7 +153,7 @@ sub send_email {
   my $FAULT = sub { $self->_throw($_[0], $smtp); };
 
   $smtp->mail(_quoteaddr($env->{from}))
-    or $FAULT->("$env->{from} failed after MAIL FROM:");
+    or $FAULT->("$env->{from} failed after MAIL FROM");
 
   my @failures;
   my @ok_rcpts;
@@ -151,7 +197,15 @@ sub send_email {
   # -- rjbs, 2008-12-04
 
   $smtp->data                        or $FAULT->("error at DATA start");
-  $smtp->datasend($email->as_string) or $FAULT->("error at during DATA");
+
+  my $msg_string = $email->as_string;
+  my $hunk_size  = $self->_hunk_size;
+
+  while (length $msg_string) {
+    my $next_hunk = substr $msg_string, 0, $hunk_size, '';
+    $smtp->datasend($next_hunk) or $FAULT->("error at during DATA");
+  }
+
   $smtp->dataend                     or $FAULT->("error at after DATA");
 
   my $message = $smtp->message;
@@ -169,6 +223,8 @@ sub send_email {
   });
 }
 
+sub _hunk_size { 2**20 } # send messages to DATA in hunks of 1 mebibyte
+
 sub success {
   my $self = shift;
   my $success = Moo::Role->create_class_with_roles('Email::Sender::Success', 'Email::Sender::Role::HasMessage')->new(@_);
@@ -181,6 +237,13 @@ sub partial_success {
 
 sub _message_complete { $_[1]->quit; }
 
+# =head1 PARTIAL SUCCESS
+#
+# If C<allow_partial_success> was set when creating the transport, the transport
+# may return L<Email::Sender::Success::Partial> objects.  Consult that module's
+# documentation.
+#
+# =cut
 
 with 'Email::Sender::Transport';
 no Moo;
@@ -190,13 +253,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Transport::SMTP - send email over SMTP
 
 =head1 VERSION
 
-version 1.300006
+version 1.300011
 
 =head1 DESCRIPTION
 
@@ -233,6 +298,8 @@ The following attributes may be passed to the constructor:
 
 =item C<localport>: local port from which to connect
 
+=item C<debug>: if true, put the L<Net::SMTP> object in debug mode
+
 =back
 
 =head1 PARTIAL SUCCESS
@@ -247,7 +314,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo Signes.
+This software is copyright (c) 2014 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
