@@ -1,12 +1,23 @@
 package Email::Sender::Transport::Sendmail;
-{
-  $Email::Sender::Transport::Sendmail::VERSION = '1.300006';
-}
-use Moo;
-use MooX::Types::MooseLike::Base qw(Str);
-with 'Email::Sender::Transport';
 # ABSTRACT: send mail via sendmail(1)
+$Email::Sender::Transport::Sendmail::VERSION = '1.300011';
+use Moo;
+with 'Email::Sender::Transport';
 
+use MooX::Types::MooseLike::Base qw(Str);
+
+# =head2 DESCRIPTION
+#
+# This transport sends mail by piping it to the F<sendmail> command.  If the
+# location of the F<sendmail> command is not provided in the constructor (see
+# below) then the library will look for an executable file called F<sendmail> in
+# the path.
+#
+# To specify the location of sendmail:
+#
+#   my $sender = Email::Sender::Transport::Sendmail->new({ sendmail => $path });
+#
+# =cut
 
 use File::Spec ();
 
@@ -58,8 +69,8 @@ sub _sendmail_pipe {
   my $prog = $self->sendmail;
 
   my ($first, @args) = $^O eq 'MSWin32'
-           ? qq(| "$prog" -f $envelope->{from} @{$envelope->{to}})
-           : (q{|-}, $prog, '-f', $envelope->{from}, @{$envelope->{to}});
+           ? qq(| "$prog" -i -f $envelope->{from} @{$envelope->{to}})
+           : (q{|-}, $prog, '-i', '-f', $envelope->{from}, '--', @{$envelope->{to}});
 
   no warnings 'exec'; ## no critic
   my $pipe;
@@ -74,6 +85,9 @@ sub send_email {
 
   my $pipe = $self->_sendmail_pipe($envelope);
 
+  my $string = $email->as_string;
+  $string =~ s/\x0D\x0A/\x0A/g unless $^O eq 'MSWin32';
+
   print $pipe $email->as_string
     or Email::Sender::Failure->throw("couldn't send message to sendmail: $!");
 
@@ -90,13 +104,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Transport::Sendmail - send mail via sendmail(1)
 
 =head1 VERSION
 
-version 1.300006
+version 1.300011
 
 =head2 DESCRIPTION
 
@@ -115,7 +131,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo Signes.
+This software is copyright (c) 2014 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
